# wai-annotations
Python library for converting between annotation formats of data domains such as images and audio.

Also offers plugins for preprocessing data, for generating statistics and visualizations,
as well as incorporating predictions made via a Redis backend (e.g., using deep learning models).

The manual is available here:

https://ufdl.cms.waikato.ac.nz/wai-annotations-manual

## Available modules

* [wai-annotations-core](https://github.com/waikato-ufdl/wai-annotations-core)
* [wai-annotations-adams](https://github.com/waikato-ufdl/wai-annotations-adams)
* [wai-annotations-bluechannel](https://github.com/waikato-ufdl/wai-annotations-bluechannel)
* [wai-annotations-coco](https://github.com/waikato-ufdl/wai-annotations-coco)
* [wai-annotations-commonvoice](https://github.com/waikato-ufdl/wai-annotations-commonvoice)
* [wai-annotations-festvox](https://github.com/waikato-ufdl/wai-annotations-festvox)
* [wai-annotations-grayscale](https://github.com/waikato-ufdl/wai-annotations-grayscale)
* [wai-annotations-imgaug](https://github.com/waikato-ufdl/wai-annotations-imgaug)
* [wai-annotations-imgstats](https://github.com/waikato-ufdl/wai-annotations-imgstats)
* [wai-annotations-imgvis](https://github.com/waikato-ufdl/wai-annotations-imgvis)
* [wai-annotations-indexedpng](https://github.com/waikato-ufdl/wai-annotations-indexedpng)
* [wai-annotations-layersegments](https://github.com/waikato-ufdl/wai-annotations-layersegments)
* [wai-annotations-opex](https://github.com/waikato-ufdl/wai-annotations-opex)
* [wai-annotations-redis-predictions](https://github.com/waikato-ufdl/wai-annotations-redis-predictions)
* [wai-annotations-roi](https://github.com/waikato-ufdl/wai-annotations-roi)
* [wai-annotations-subdir](https://github.com/waikato-ufdl/wai-annotations-subdir)
* [wai-annotations-tf](https://github.com/waikato-ufdl/wai-annotations-tf)
* [wai-annotations-vgg](https://github.com/waikato-ufdl/wai-annotations-vgg)
* [wai-annotations-video](https://github.com/waikato-ufdl/wai-annotations-video)
* [wai-annotations-voc](https://github.com/waikato-ufdl/wai-annotations-voc)
* [wai-annotations-yolo](https://github.com/waikato-ufdl/wai-annotations-yolo)

## Docker images

Public [docker images](docker) with all the modules installed are available from here:

https://hub.docker.com/r/waikatoufdl/wai.annotations/

## Bash script

The [install.sh](install.sh) bash script allows you to install wai.annotations in a
virtual environment. Either using the published modules or from the latest source
code available from the github repositories.
